#
# spec file for package gap-guava
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-guava
Version:        3.20
Release:        2.1
Summary:        GAP package for computing with error-correcting codes
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/guava/
#Git-Clone:     https://github.com/gap-packages/guava
Source:         https://github.com/gap-packages/guava/releases/download/v%version/guava-%version.tar.gz
BuildRequires:  gap-devel >= 4.8.0
BuildRequires:  gap-rpm-devel
BuildRequires:  libtool
Requires:       gap-core >= 4.8.0
Suggests:       gap-sonata >= 2.3

%description
GUAVA is a package that implements coding theory algorithms in GAP.
With GUAVA, codes can be created and manipulated and information
about codes can be calculated.

GUAVA consists of various files written in the GAP language, and an
external program for dealing with automorphism groups of codes and
isomorphism testing functions. Several algorithms that need the speed
are integrated in the GAP kernel.

%prep
%setup -qn guava-%version

%build
./configure "%gapdir"
cd src/leon/
export CFLAGS="%optflags -Wno-error=return-type"
%configure
cd -
%make_build -j1

%install
%gappkg_simple_install
rm -Rf "%buildroot/$moddir/src"

%files -f %name.files

%changelog
* Thu Feb 27 2025 Jan Engelhardt <jengelh@inai.de>
- Make specfile conform to POSIX sh
* Sun Feb  9 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.20
  * Many changes to the manual were made. Accumulated anachronisms
    were revealed by manual/example test extraction via AutoDoc.
  * Adjusted old C code to not define a bool type (the C23 standard
    will override it soon for gcc).
  * CoveringRadius() for codes over small non-binary fields was
    throwing an error.
* Thu Mar 21 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.19
  * Fix various issues in the C source code, including potential
    buffer overflows and many compiler warnings
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.18
  * Build system updates only; no user-visible changes
* Fri Oct 14 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to new upstream release 3.17
  + Add back QCLDPCCodeFromGroup method (it was accidentally
    removed between Guava 3.8 and 3.9)
  + Fix out of bounds access in the C code
  + Fix most (all?) compiler warnings in the C code
  + Fix PutStandardForm *again*
  + Update several outdated manual examples
  + Avoid accidentally displaying the output of subprocesses to
    the user
  + Improve the package banner
  + Various minor and/or janitorial changes
- Update to new upstream release 3.16
  + CirculantMatrixi() now circulates to the right.
- Update to new upstream release 3.15
  + Fixed decoding of cyclic codes
  + Several updates to build system
- Fix license (GPL-2.0-or-later, according to PackageInfo)
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.14
  * The external binaries from J. S. Leon and Cen Tjhai can now
    be used on all architectures.
  * The decoding method for cyclic codes fails in certain
    situations. We are leaving this as a known bug for the
    moment.
  * Constructions were added for several of the optimal codes in
    the bounds tables that were referenced in the now defunct
    online table by Brouwer and Verhoeff.
- Remove guava-make.diff (obsolete)
* Sat Sep  9 2017 jengelh@inai.de
- Add guava-make.diff
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 3.13
  * No changelog was provided
* Fri May 10 2013 jengelh@inai.de
- Split guava (version 3.12) off the gap RPM package
